@@ -8,10 +8,10 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package MooseX::TrackDirty::Attributes::Trait::Method::Accessor;
-{
-  $MooseX::TrackDirty::Attributes::Trait::Method::Accessor::VERSION = '2.002';
+BEGIN {
+  $MooseX::TrackDirty::Attributes::Trait::Method::Accessor::AUTHORITY = 'cpan:RSRCHBOY';
 }
-
+$MooseX::TrackDirty::Attributes::Trait::Method::Accessor::VERSION = '2.003';
 # ABSTRACT: Track dirtied attributes
 
 use Moose::Role;
@@ -128,9 +128,11 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
-=for :stopwords Chris Weyl Gianni Ceccarelli attribute's
+=for :stopwords Chris Weyl Ceccarelli Gianni attribute's
+
+=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
 
 =head1 NAME
 
@@ -138,7 +140,7 @@ MooseX::TrackDirty::Attributes::Trait::Method::Accessor - Track dirtied attribut
 
 =head1 VERSION
 
-This document describes version 2.002 of MooseX::TrackDirty::Attributes::Trait::Method::Accessor - released November 24, 2012 as part of MooseX-TrackDirty-Attributes.
+This document describes version 2.003 of MooseX::TrackDirty::Attributes::Trait::Method::Accessor - released December 23, 2014 as part of MooseX-TrackDirty-Attributes.
 
 =head1 DESCRIPTION
 
@@ -163,8 +165,8 @@ L<MooseX::TrackDirty::Attributes>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/RsrchBoy/moosex-trackdirty-attributes>
-and may be cloned from L<git://github.com/RsrchBoy/moosex-trackdirty-attributes.git>
+The development version is on github at L<http://https://github.com/RsrchBoy/moosex-trackdirty-attributes>
+and may be cloned from L<git://https://github.com/RsrchBoy/moosex-trackdirty-attributes.git>
 
 =head1 BUGS
 
@@ -179,9 +181,24 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
-=head1 CONTRIBUTOR
+=head2 I'm a material boy in a material world
 
-Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
+=begin html
+
+<a href="https://www.gittip.com/RsrchBoy/"><img src="https://raw.githubusercontent.com/gittip/www.gittip.com/master/www/assets/%25version/logo.png" /></a>
+<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
+<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-trackdirty-attributes&title=RsrchBoy's%20CPAN%20MooseX-TrackDirty-Attributes&tags=%22RsrchBoy's%20MooseX-TrackDirty-Attributes%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
+
+=end html
+
+Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
+rather B<it is simply a very pleasant surprise>. I largely create and release
+works like this because I need them or I find it enjoyable; however, don't let
+that stop you if you feel like it ;)
+
+L<Flattr this|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fmoosex-trackdirty-attributes&title=RsrchBoy's%20CPAN%20MooseX-TrackDirty-Attributes&tags=%22RsrchBoy's%20MooseX-TrackDirty-Attributes%20in%20the%20CPAN%22>,
+L<gittip me|https://www.gittip.com/RsrchBoy/>, or indulge my
+L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If you so desire.
 
 =head1 COPYRIGHT AND LICENSE
 
